<?php

namespace Drupal\flag_lists\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Link;

/**
 * Class FlaggingCollectionSettingsForm.
 *
 * @ingroup flag_lists
 */
class FlagListsSettingForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['flag_lists.settings'];
  }

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'flag_lists_settings_form';
  }

  /**
   * Form submission handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {

    $this->config('flag_lists.settings')
      ->set('hide_collections',
      $form_state->getValue('hide_collections'))
      ->save();
    $this->config('flag_lists.settings')
      ->set('hide_actions',
      $form_state->getValue('hide_actions'))
      ->save();
  }

  /**
   * Defines the settings form for Flagging collection entities.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   Form definition array.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('flag_lists.settings');

    $form['flag_settings'] = [
      '#type' => 'fieldset',
      '#title' => $this->t('Overview Settings'),
    ];
    $flagOverviewLink = Link::createFromRoute(
      'Flag Overview',
      'entity.flag.collection'
      )
      ->toString();
    $form['flag_settings']['hide_collections'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide Flagging Collections in the @link',
         ['@link' => $flagOverviewLink]
      ),
      '#default_value' => $config->get('hide_collections'),
      '#description' => $this->t('Do you want to hide the Flagging Collections in the @link?',
        ['@link' => $flagOverviewLink]
      ),
    ];
    $actionOverviewLink = Link::createFromRoute(
      'Action Overview',
      'entity.action.collection'
      )
      ->toString();
    $form['flag_settings']['hide_actions'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Hide Flagging Collection Actions in the @link',
         ['@link' => $actionOverviewLink]
      ),
      '#default_value' => $config->get('hide_actions'),
      '#description' => $this->t('Do you want to hide the Flagging Collectioni Actions in the @link?',
        ['@link' => $actionOverviewLink]
      ),
    ];

    return parent::buildForm($form, $form_state);
  }

}
